..
    Copyright (C) 2020 CERN.
    Copyright (C) 2020 Northwestern University.

    Marshmallow-Utils is free software; you can redistribute it and/or
    modify it under the terms of the MIT License; see LICENSE file for more
    details.

Authors
=======

Extras and utilities for Marshmallow

- Lars Holm Nielsen <lars.holm.nielsen@cern.ch>
- Guillaume Viger <guillaume.viger@northwestern.edu>
